@@ -1,11 +1,12 @@
-# mypy: ignore-errors
-
 import inspect
-from typing import Tuple
+from typing import Any, Dict, Optional, Tuple, TYPE_CHECKING
 import warnings
 
 import torch
 
+if TYPE_CHECKING:
+    from pytorch_pfn_extras.runtime._runtime import DeviceLike
+
 
 class LazyInitializationMixin:
 
@@ -37,10 +38,10 @@ class LazyInitializationMixin:
     lazy_buffer_names: Tuple[str, ...] = ()
     lazy_parameter_names: Tuple[str, ...] = ()
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self: Any, *args: Any, **kwargs: Any) -> None:
         self._lazy_ready = False
 
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)  # type: ignore[call-arg]
 
         for name in self.lazy_buffer_names:
             self.register_buffer(name, torch.Tensor([]))
@@ -50,7 +51,7 @@ class LazyInitializationMixin:
         self._lazy_ready = True
 
     @property
-    def lazy_parmeters_determined(self):
+    def lazy_parmeters_determined(self) -> bool:
         """Returns if all lazy parameters are determined.
 
         Subclasses can perform parameters initialization after all lazy
@@ -61,7 +62,8 @@ class LazyInitializationMixin:
             not isinstance(getattr(self, x), UninitializedParameter)
             for x in self.lazy_parameter_names])
 
-    def state_dict(self, *args, **kwargs):
+    def state_dict(
+            self: Any, *args: Any, **kwargs: Any) -> Dict[str, Any]:
         """Returns a dictionary containing a whole state of the module.
 
         This function overrides the default behavior to exclude uninitialized
@@ -72,13 +74,13 @@ class LazyInitializationMixin:
 
         See comments of ``_lazy_load_hook`` for details.
         """
-        destination = super().state_dict(*args, **kwargs)
+        destination = super().state_dict(*args, **kwargs)  # type: ignore[misc]
         for name in self.lazy_parameter_names:
             if isinstance(getattr(self, name), UninitializedParameter):
                 del destination[name]
-        return destination
+        return destination  # type: ignore[no-any-return]
 
-    def _lazy_load_hook(
+    def _lazy_load_hook(  # type: ignore[no-untyped-def]
             self, state_dict, prefix, local_metadata, strict,
             missing_keys, unexpected_keys, error_msgs):
         """load_state_dict pre-hook function for lazy buffers and parameters.
@@ -127,29 +129,35 @@ class LazyInitializationMixin:
 
 class UninitializedParameter(torch.nn.Parameter):
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return 'Uninitialized lazy parameter'
 
-    def share_memory_(self):
+    def share_memory_(self) -> 'UninitializedParameter':
         raise RuntimeError(
             'Can\'t share memory on an unitialized parameter. '
             'Run forward to initialize the network before calling '
             '`module.share_memory()`.')
 
     @property
-    def is_leaf(self):
+    def is_leaf(self) -> bool:  # type: ignore[override]
         # Hacky workaround to detect use of uninitialized lazy parameters.
         # This overrides ``is_leaf`` attribute which should always be ``True``
         # for parameters; optimizers check for this attribute and raise an
         # error if non-leaf tensors are detected.
         frame = inspect.currentframe()
-        if frame.f_back.f_globals['__package__'].startswith('torch.optim'):
+        package_name = frame.f_back.f_globals['__package__']  # type: ignore
+        if package_name.startswith('torch.optim'):
             warnings.warn('''
     Use of uninitialized lazy parameter in Optimizer has been detected.
     Maybe you forgot to run forward before passing `module.parameters()` to the optimizer?''')  # NOQA
         return True
 
-    def materialize(self, shape, device=None, dtype=None):
+    def materialize(
+            self,
+            shape: Tuple[int, ...],
+            device: Optional['DeviceLike'] = None,
+            dtype: Optional[torch.dtype] = None,
+    ) -> None:
         r"""Create a Parameter with the same properties of the uninitialized
         one. Given a shape, it materializes a parameter in the same device
         and with the same `dtype` as the current one or the specified ones in
@@ -169,4 +177,4 @@ class UninitializedParameter(torch.nn.Parameter):
         if dtype is None:
             dtype = self.data.dtype
         self.data = torch.empty(shape, device=device, dtype=dtype)
-        self.__class__ = torch.nn.Parameter
+        self.__class__ = torch.nn.Parameter  # type: ignore[assignment]
