@@ -1,12 +1,11 @@
-# mypy: ignore-errors
-
 import collections
 import json
-from typing import List
+from typing import Any, Callable, Dict, Iterable, List, Mapping, Optional
 
 from pytorch_pfn_extras import reporting
 from pytorch_pfn_extras.training import extension
 from pytorch_pfn_extras.training import trigger as trigger_module
+from pytorch_pfn_extras.training._manager_protocol import ExtensionsManagerProtocol
 
 try:
     import pandas
@@ -18,11 +17,11 @@ except ImportError:
 
 class LogWriterSaveFunc:
 
-    def __init__(self, format, append):
+    def __init__(self, format: str, append: bool) -> None:
         self._format = format
         self._append = append
 
-    def __call__(self, target, file_o):
+    def __call__(self, target: Dict[str, Any], file_o: Any) -> None:
         if self._format == 'json':
             if self._append:
                 raise ValueError(
@@ -35,9 +34,10 @@ class LogWriterSaveFunc:
             import yaml
 
             # This is to dump ordered dicts as regular dicts
-            def dict_representer(dumper, data):
+            def dict_representer(dumper: Any, data: Any) -> Any:
                 return dumper.represent_dict(data.items())
-            yaml.add_representer(collections.OrderedDict, dict_representer)
+            yaml.add_representer(  # type: ignore[no-untyped-call]
+                collections.OrderedDict, dict_representer)
             # yaml.add_constructor(_mapping_tag, dict_constructor)
             log = yaml.dump(target)
         else:
@@ -48,8 +48,8 @@ class LogWriterSaveFunc:
 class _LogBuffer:
 
     def __init__(self) -> None:
-        self.lookers = {}
-        self._log = []
+        self.lookers: Dict[int, int] = {}
+        self._log: List[Any] = []
         self._offset = 0
 
     def _trim(self) -> None:
@@ -58,10 +58,10 @@ class _LogBuffer:
             self._log = self._log[min_looker_index - self._offset:]
             self._offset = min_looker_index
 
-    def append(self, observation) -> None:
+    def append(self, observation: Any) -> None:
         self._log.append(observation)
 
-    def _get(self, looker_id: int) -> List[str]:
+    def _get(self, looker_id: int) -> List[Any]:
         return self._log[self.lookers[looker_id] - self._offset:]
 
     def _clear(self, looker_id: int) -> None:
@@ -86,7 +86,7 @@ class _LogLooker:
         self._log_buffer = log_buffer
         self._looker_id = looker_id
 
-    def get(self) -> List[str]:
+    def get(self) -> List[Any]:
         return self._log_buffer._get(self._looker_id)
 
     def clear(self) -> None:
@@ -151,8 +151,16 @@ class LogReport(extension.Extension):
         iterations already done.
     """
 
-    def __init__(self, keys=None, trigger=(1, 'epoch'), postprocess=None,
-                 filename=None, append=False, format=None, **kwargs):
+    def __init__(
+            self,
+            keys: Optional[Iterable[str]] = None,
+            trigger: trigger_module.TriggerLike = (1, 'epoch'),
+            postprocess: Optional[Callable[[Mapping[str, Any]], None]] = None,
+            filename: Optional[str] = None,
+            append: bool = False,
+            format: Optional[str] = None,
+            **kwargs: Any,
+    ):
         self._keys = keys
         self._trigger = trigger_module.get_trigger(trigger)
         self._postprocess = postprocess
@@ -180,7 +188,7 @@ class LogReport(extension.Extension):
         self._format = format
         self._init_summary()
 
-    def __call__(self, manager):
+    def __call__(self, manager: ExtensionsManagerProtocol) -> None:
         # accumulate the observations
         keys = self._keys
         observation = manager.observation
@@ -191,7 +199,7 @@ class LogReport(extension.Extension):
         else:
             summary.add({k: observation[k] for k in keys if k in observation})
 
-        writer = manager.writer if self._writer is None else self._writer
+        writer: Any = manager.writer if self._writer is None else self._writer
 
         if manager.is_before_training or self._trigger(manager):
             # output the result
@@ -222,12 +230,12 @@ class LogReport(extension.Extension):
             self._init_summary()
 
     @property
-    def log(self):
+    def log(self) -> List[str]:
         """The current list of observation dictionaries."""
         return self._log_looker.get()
 
-    def state_dict(self):
-        state = {}
+    def state_dict(self) -> Dict[str, Any]:
+        state: Dict[str, Any] = {}
         if hasattr(self._trigger, 'state_dict'):
             state['_trigger'] = self._trigger.state_dict()
 
@@ -238,18 +246,22 @@ class LogReport(extension.Extension):
         state['_log'] = json.dumps(self._log_buffer._log)
         return state
 
-    def load_state_dict(self, to_load):
+    def load_state_dict(self, to_load: Dict[str, Any]) -> None:
         if hasattr(self._trigger, 'load_state_dict'):
             self._trigger.load_state_dict(to_load['_trigger'])
         self._summary.load_state_dict(to_load['_summary'])
         self._log_buffer._log = json.loads(to_load['_log'])
 
-    def _init_summary(self):
+    def _init_summary(self) -> None:
         self._summary = reporting.DictSummary()
 
-    def to_dataframe(self):
+    def to_dataframe(self) -> 'pandas.DataFrame':
         if not _pandas_available:
             raise ImportError(
                 "Need to install pandas to use `to_dataframe` method."
             )
         return pandas.DataFrame(self._log_looker.get())
+
+    def finalize(self) -> None:
+        if self._writer is not None:
+            self._writer.finalize()
