@@ -1,12 +1,12 @@
-# mypy: ignore-errors
-
-import json
 from collections import OrderedDict
+import json
+from typing import Any, Dict, Iterable, List, Optional
 
 from pytorch_pfn_extras import reporting
 from pytorch_pfn_extras.training import extension
 from pytorch_pfn_extras.training.extensions import log_report
 from pytorch_pfn_extras.training import trigger as trigger_module
+from pytorch_pfn_extras.training._manager_protocol import ExtensionsManagerProtocol
 from pytorch_pfn_extras.profiler._time_summary import get_time_summary
 
 
@@ -45,14 +45,14 @@ class ProfileReport(extension.Extension):
         templates (str): template string for print values.
     """
     def __init__(
-        self,
-        store_keys=None,
-        report_keys=None,
-        trigger=(1, "epoch"),
-        filename=None,
-        append=False,
-        format=None,
-        **kwargs,
+            self,
+            store_keys: Optional[Iterable[str]] = None,
+            report_keys: Optional[Iterable[str]] = None,
+            trigger: trigger_module.TriggerLike = (1, "epoch"),
+            filename: Optional[str] = None,
+            append: bool = False,
+            format: Optional[str] = None,
+            **kwargs: Any,
     ):
         self.time_summary = get_time_summary()
         # Initializes global TimeSummary.
@@ -66,7 +66,7 @@ class ProfileReport(extension.Extension):
             ]
         self._report_keys = report_keys
         self._trigger = trigger_module.get_trigger(trigger)
-        self._log = []
+        self._log: List[Any] = []
 
         log_name = kwargs.get("log_name", "log")
         if filename is None:
@@ -86,7 +86,7 @@ class ProfileReport(extension.Extension):
         self._append = append
         self._format = format
 
-    def __call__(self, manager):
+    def __call__(self, manager: ExtensionsManagerProtocol) -> None:
         if manager.is_before_training or self._trigger(manager):
             with self.time_summary.summary(clear=True) as s:
                 st, additional = s
@@ -121,21 +121,26 @@ class ProfileReport(extension.Extension):
             # write to the log file
             if self._log_name is not None:
                 log_name = self._log_name.format(**out)
+                assert self._format is not None
                 savefun = log_report.LogWriterSaveFunc(
                     self._format, self._append)
-                writer(log_name, out, self._log,
+                writer(log_name, out, self._log,  # type: ignore
                        savefun=savefun, append=self._append)
                 if self._append:
                     self._log = []
 
-    def state_dict(self):
-        state = {}
+    def state_dict(self) -> Dict[str, Any]:
+        state: Dict[str, Any] = {}
         if hasattr(self._trigger, "state_dict"):
             state["_trigger"] = self._trigger.state_dict()
         state["_log"] = json.dumps(self._log)
         return state
 
-    def load_state_dict(self, to_load):
+    def load_state_dict(self, to_load: Dict[str, Any]) -> None:
         if hasattr(self._trigger, "load_state_dict"):
             self._trigger.load_state_dict(to_load["_trigger"])
         self._log = json.loads(to_load["_log"])
+
+    def finalize(self) -> None:
+        if self._writer is not None:
+            self._writer.finalize()
