@@ -1,9 +1,15 @@
-# mypy: ignore-errors
+from typing import Any, Callable
+
+import torch.optim
 
 from pytorch_pfn_extras.training import extension
+from pytorch_pfn_extras.training._manager_protocol import ExtensionsManagerProtocol
 
 
-def observe_value(observation_key, target_func):
+def observe_value(
+        observation_key: str,
+        target_func: Callable[[ExtensionsManagerProtocol], Any],
+) -> Callable[[ExtensionsManagerProtocol], None]:
     """Returns an extension to continuously record a value.
 
     Args:
@@ -22,12 +28,16 @@ def observe_value(observation_key, target_func):
     """
     @extension.make_extension(
         trigger=(1, 'epoch'), priority=extension.PRIORITY_WRITER)
-    def _observe_value(manager):
+    def _observe_value(manager: ExtensionsManagerProtocol) -> None:
         manager.observation[observation_key] = target_func(manager)
     return _observe_value
 
 
-def observe_lr(optimizer, param_group=0, observation_key='lr'):
+def observe_lr(
+        optimizer: torch.optim.Optimizer,
+        param_group: int = 0,
+        observation_key: str = 'lr',
+) -> Any:
     """Returns an extension to record the learning rate.
 
     Args:
