@@ -1,5 +1,3 @@
-# mypy: ignore-errors
-
 from typing import Any, Dict
 
 from pytorch_pfn_extras.training import trigger
@@ -46,5 +44,5 @@ class OnceTrigger(trigger.Trigger):
     def load_state_dict(self, to_load: Dict[str, Any]) -> None:
         self._flag_first = to_load['_flag_first']
 
-    def may_fire(self, iteration, epoch_length):
+    def may_fire(self, iteration: int, epoch_length: int) -> bool:
         return not (self._flag_first or self._flag_resumed)
