@@ -1,7 +1,8 @@
 import collections
-import json
+import pathlib
 import re
 import threading
+import weakref
 import concurrent.futures
 from typing import (
     Any, Callable, Dict, Iterable, List, Mapping, Optional, Sequence,
@@ -11,8 +12,6 @@ from typing import (
 import torch.nn
 import torch.testing
 
-import pytorch_pfn_extras as ppe
-from pytorch_pfn_extras import engine as _engine_module
 from pytorch_pfn_extras import handler as _handler_module
 from pytorch_pfn_extras.handler import _logic
 from pytorch_pfn_extras.training import _trainer
@@ -58,7 +57,6 @@ class _ComparableHandler(_handler_module.BaseHandler):
 
     def train_epoch_end(self, trainer: _trainer._Trainer) -> None:
         self._handler.train_epoch_end(trainer)
-        self._epoch = None
 
     def train_validation_begin(
             self, trainer: _trainer._Trainer, evaluator: _evaluator.Evaluator) -> None:
@@ -134,7 +132,7 @@ class _ComparableHandler(_handler_module.BaseHandler):
     def _compare(self, engine: Any, batch_idx: int, outputs: Any) -> None:
         outputs = _logic._normalize_outputs(outputs)
         target = self._get_target_cb(self, engine, batch_idx, outputs)
-        self._compare_cb(self, engine, batch_idx, target)
+        self._compare_cb(self.name, engine, batch_idx, target)
 
     def _reset_intermediate_values(self) -> None:
         assert self._batch_idx is not None
@@ -318,16 +316,16 @@ class _ComparerBase:
 
     def compare_targets(
             self,
-            handler: _ComparableHandler,
+            name: str,
             engine: _Engine,
             batch_idx: int,
             target: Dict[str, Any],
     ) -> None:
-        self._iters[handler.name] += 1
-        if (self.n_iters is None) or (self._iters[handler.name] % self.n_iters == 0):
+        self._iters[name] += 1
+        if (self.n_iters is None) or (self._iters[name] % self.n_iters == 0):
             # Save the outputs of this iteration
             with self.report_lock:
-                self.targets[handler.name] = target
+                self.targets[name] = target
                 if len(self.targets.keys()) == len(self.engines.keys()):
                     # all outputs have been filled, lets compare and reset
                     _compare_targets(self.compare_fn, self.targets, None, batch_idx)
@@ -531,7 +529,8 @@ class Comparer:
         """
         self._engine_type: Optional[Type[_Engine]] = None
         self._engines: Dict[
-            str, Tuple[_Engine, Any, Any]] = collections.OrderedDict()
+            str, Tuple[Union[_Engine, _LoadDumpsEngine], Any, Any]
+        ] = collections.OrderedDict()
         self._compare_fn = compare_fn
         self._targets: Dict[str, Dict[str, Any]] = {}
         self._output_keys = outputs
@@ -544,6 +543,7 @@ class Comparer:
         # Synchronizes iteration timing
         self._barrier: Optional[threading.Barrier] = None
         self._report_lock = threading.Lock()  # Locks `Comparer._get_target`
+        self._count = 0
 
         if trigger is None:
             self._trigger = trigger_module.get_trigger((1, "epoch"))
@@ -573,12 +573,12 @@ class Comparer:
         if not condition:
             raise ValueError("Engines have different triggers.")
 
-    @staticmethod
-    def _get_filename(engine: _Engine, batch_idx: int) -> str:
-        name = type(engine).__name__
-        handler = engine.handler
-        assert isinstance(handler, _ComparableHandler)
-        epoch = handler._epoch
+    def _get_filename(
+            self, engine: _Engine, handler_name: str, batch_idx: int) -> str:
+        name = f'dump_{self._count:08}'
+        name += '_' + type(engine).__name__
+        orig_engine, _, _ = self._engines[handler_name]
+        epoch = orig_engine.handler._epoch  # type: ignore
         if epoch is not None:
             name += f'_epoch_{epoch}'
         name += f'_iter_{batch_idx}'
@@ -586,19 +586,20 @@ class Comparer:
 
     def _compare_targets(
             self,
-            handler: _ComparableHandler,
+            name: str,
             engine: _Engine,
             batch_idx: int,
             target: Dict[str, Any],
     ) -> None:
         # Save the outputs of this iteration
         with self._report_lock:
-            self._targets[handler.name] = target
+            self._targets[name] = target
             if len(self._targets.keys()) == len(self._engines.keys()):
                 # all outputs have been filled, lets compare and reset
                 _compare_targets(
                     self._compare_fn, self._targets, self._baseline, batch_idx)
                 self._targets = {}
+                self._count += 1
             self._assert_incompatible_trigger(not self._finalized)
 
         # Excplicitly synchronize
@@ -645,17 +646,6 @@ class Comparer:
 
         self._engines[name] = engine, args, kwargs
 
-    def _load_dump(
-            self,
-            handler: _ComparableHandler,
-            engine: _Engine,
-            batch_idx: int,
-            outputs: Dict[str, Any],
-    ) -> Dict[str, Dict[str, Any]]:
-        name = self._get_filename(engine, batch_idx)
-        assert isinstance(engine.handler, _ComparableHandler)
-        return torch.load(f'{engine.handler._dir}/{name}')  # type: ignore
-
     def add_dump(self, name: str, dir: str) -> None:
         """Add an engine to compare variables.
 
@@ -665,54 +655,20 @@ class Comparer:
             dir (str):
                 The directory that the results are saved to.
         """
-        with open(f'{dir}/summary') as f:
-            summary = json.loads(f.read())
-
-        class DummyModel(torch.nn.Module):
-            def __init__(self) -> None:
-                super().__init__()  # type: ignore[no-untyped-call]
-                self.param = torch.nn.Parameter(torch.tensor(1.0))
-
-            def forward(self, *args: Any, **kwargs: Any) -> Any:
-                return ()
-
-        model = DummyModel()
-        ppe.to(model, 'cpu')
-
-        # Create a dummy engine
-        evaluator: Optional[_evaluator.Evaluator] = None
-        trainer: Optional[_trainer.Trainer] = None
-        args = []
-        if summary['evaluator']:
-            evaluator = _engine_module.create_evaluator(model)
-            args = [[None] * summary['eval_len']]
-        if summary['trainer']:
-            trainer = _engine_module.create_trainer(
-                {'main': model},
-                {'main': torch.optim.SGD(model.parameters(), lr=0.01)},
-                summary['max_epochs'],
-                evaluator=evaluator,
-            )
-            args = [[None] * summary['train_len']] + args
-
-        engine = trainer or evaluator
-        assert engine is not None
-        _overwrite_handler(
-            engine, name, self._load_dump, self._compare_targets,
-            self._trigger, dir=dir)
-
-        self._engines[name] = engine, args, {}
+        engine = _LoadDumpsEngine(self, name, dir)
+        self._engines[name] = engine, (), {}
 
     def _dump_targets(
             self,
-            handler: _ComparableHandler,
+            name: str,
             engine: _Engine,
             batch_idx: int,
             target: Dict[str, Any],
     ) -> None:
-        name = self._get_filename(engine, batch_idx)
+        name = self._get_filename(engine, name, batch_idx)
         assert isinstance(engine.handler, _ComparableHandler)
         torch.save(target, f'{engine.handler._dir}/{name}')
+        self._count += 1
 
     def dump(self, engine: _Engine, dir: str, *args: Any, **kwargs: Any) -> None:
         """Add an engine to compare variables.
@@ -725,24 +681,20 @@ class Comparer:
             *args and **kwargs:
                 Arguments passed to ``engine.run``.
         """
-        _overwrite_handler(
-            engine, '', self._get_target, self._dump_targets, self._trigger, dir=dir)
+        pathlib.Path(dir).mkdir(parents=True, exist_ok=True)
 
+        self._count = 0
+        name = '__dump'
+        _overwrite_handler(
+            engine, name, self._get_target, self._dump_targets,
+            self._trigger, dir=dir)
+
+        self._engines[name] = engine, args, {}
         engine.run(*args, **kwargs)
+        self._engines.pop(name)
+
         assert isinstance(engine.handler, _ComparableHandler)
         engine.handler = engine.handler._handler
-        summary = {
-            'evaluator': (isinstance(engine, _evaluator.Evaluator)
-                          or getattr(engine, 'evaluator', None) is not None),
-            'trainer': isinstance(engine, _trainer.Trainer),
-            'train_len': getattr(engine, '_train_len', None),
-            'eval_len': engine._eval_len,
-        }
-        if isinstance(engine,_trainer.Trainer):
-            assert engine._manager is not None
-            summary['max_epochs'] = engine._manager.max_epochs
-        with open(f'{dir}/summary', 'w') as f:
-            f.write(json.dumps(summary))
 
     def _run_engine(self, engine: _Engine, args: Any, kwargs: Any) -> None:
         assert self._semaphore is not None
@@ -762,6 +714,7 @@ class Comparer:
     def compare(self) -> None:
         """Compares outputs.
         """
+        self._count = 0
         n_workers = len(self._engines)
         self._barrier = threading.Barrier(n_workers)
         self._semaphore = threading.Semaphore(
@@ -778,3 +731,23 @@ def intermediate_value(name: str, value: torch.Tensor) -> None:
     if not hasattr(_thread_local, 'handler'):
         return
     _thread_local.handler._add_intermediate_value(name, value)
+
+
+class _LoadDumpsEngine:
+    def __init__(self, comparer: Comparer, name: str, dir: str) -> None:
+        self.name = name
+        self._comparer_ref = weakref.ref(comparer)
+        self._dir = dir
+
+    def run(self) -> None:
+        comparer = self._comparer_ref()
+        assert comparer is not None
+        for path in sorted(pathlib.Path(self._dir).iterdir()):
+            filename = path.name
+            if filename.startswith('dump_'):
+                target = torch.load(path)  # type: ignore[no-untyped-call]
+                iter_str = '_iter_'
+                pos = filename.find(iter_str)
+                batch_idx = int(filename[pos + len(iter_str):])
+                comparer._compare_targets(
+                    self.name, None, batch_idx, target)  # type: ignore
